@@ -4,9 +4,9 @@ from logging import getLogger
 from shutil import rmtree
 
 from pki.openssl import OpensslActions, OpensslCaManagement, md5_constructor, refresh_pki_metadata
-from pki.settings import ADMIN_MEDIA_PREFIX, PKI_BASE_URL, PKI_DEFAULT_COUNTRY
+from pki.settings import ADMIN_MEDIA_PREFIX, MEDIA_URL, PKI_BASE_URL, PKI_DEFAULT_COUNTRY, PKI_ENABLE_GRAPHVIZ
 
-import datetime
+import datetime, os
 
 logger = getLogger("pki")
 
@@ -148,7 +148,22 @@ class CertificateBase(models.Model):
                 result.append( '<font color="grey">%s</font>' % i )
         
         return result
-
+    
+    def Locate_link(self):
+        
+        type = "cert"
+        
+        if self.__class__.__name__ == "CertificateAuthority":
+            type = "ca"
+        
+        if PKI_ENABLE_GRAPHVIZ:
+            return '<center><a href="%s/pki/locate/%s/%d" target="_blank"><img src="%s/pki/img/mag.png" height="13px" width="13px" alt="Locate" title="Locate object in PKI tree"/></a></center>' % (PKI_BASE_URL, type, self.pk, os.path.join(PKI_BASE_URL, MEDIA_URL))
+        else:
+            return '<center><img src="%s/pki/img/mag_disabled.png" alt="Locate" title="Enable setting PKI_ENABLE_GRAPHVIZ"/></center>' % os.path.join(PKI_BASE_URL, MEDIA_URL)
+    
+    Locate_link.allow_tags = True
+    Locate_link.short_description = 'Find'
+    
 ##------------------------------------------------------------------##
 ## Certificate authority class
 ##------------------------------------------------------------------##
@@ -449,6 +464,17 @@ class CertificateAuthority(CertificateBase):
     
     download.allow_tags = True
     
+    def Tree_link(self):
+        
+        if PKI_ENABLE_GRAPHVIZ:
+            return '<center><a href="%s/pki/tree/%d" target="_blank"><img src="%s/pki/img/tree.png" height="13px" width="13px" alt="Tree" title="Show full CA tree"/></a></center>' % (PKI_BASE_URL, self.pk, os.path.join(PKI_BASE_URL, MEDIA_URL))
+        else:
+            return '<center><img src="%s/pki/img/tree_disabled.png" alt="Tree" title="Enable setting PKI_ENABLE_GRAPHVIZ"/></center>' % os.path.join(PKI_BASE_URL, MEDIA_URL)
+    
+    Tree_link.allow_tags = True
+    Tree_link.short_description = 'Tree'
+
+    
 ##------------------------------------------------------------------##
 ## Certificate class
 ##------------------------------------------------------------------##
