@@ -9,9 +9,11 @@ from pki.settings import PKI_DIR, PKI_LOG, MEDIA_URL
 from pki.models import CertificateAuthority, Certificate
 from pki.openssl import OpensslActions
 from pki.forms import CaPassphraseForm
+from pki.graphviz import ObjectLocation, ObjectTree
 
 import os, sys
 import logging
+import tempfile
 
 logger = logging.getLogger("pki")
 
@@ -99,6 +101,59 @@ def pki_download(request, type, id, item):
         logger.error( "File not found: %s" % pki_data[category][item]['local'] )
         raise Http404
 
+def pki_locate(request, type, id):
+    """Create PNG using graphviz and return it to the user"""
+    
+    obj = None
+    
+    if type == "ca":
+        obj = get_object_or_404(CertificateAuthority, pk=id)
+    elif type == "cert":
+        obj = get_object_or_404(Certificate, pk=id)
+    
+    png = os.path.join(tempfile.gettempdir(), "%s_%s_%s" % (request.user, request.session.session_key, id))
+
+    ObjectLocation(obj, png)
+    
+    try:
+        if os.path.exists(png):
+            f = open(png)
+            x = f.read()
+            f.close()
+            
+            os.remove(png)
+    except OSError,e:
+        logger.error( "Failed to load depency tree: %s" % e)
+        raise Exception( e )
+    
+    response = HttpResponse(x, mimetype='image/png')
+    return response
+
+def pki_tree(request, id):
+    """Create PNG using graphviz and return it to user"""
+    
+    obj = None
+    
+    obj = get_object_or_404(CertificateAuthority, pk=id)
+    png = os.path.join(tempfile.gettempdir(), "%s_%s_%s" % (request.user, request.session.session_key, id))
+    
+    ObjectTree(obj, png)
+    
+    try:
+        if os.path.exists(png):
+            f = open(png)
+            x = f.read()
+            f.close()
+            
+            os.remove(png)
+    except OSError,e:
+        logger.error( "Failed to load depency tree: %s" % e)
+        raise Exception( e )
+    
+    response = HttpResponse(x, mimetype='image/png')
+    return response
+
+
 ##------------------------------------------------------------------##
 ## Admin views
 ##------------------------------------------------------------------##
